.. _metrics_api:

Classification Metrics
================================

.. automodule:: imbalanced_ensemble.metrics
    :no-members:
    :no-inherited-members:

.. currentmodule:: imbalanced_ensemble.metrics

.. autosummary::
   :toctree: _autosummary
   :template: function.rst

   sensitivity_specificity_support
   sensitivity_score
   specificity_score
   geometric_mean_score
   make_index_balanced_accuracy
   classification_report_imbalanced
   macro_averaged_mean_absolute_error